core/hardware_core library

Classes

HardwareEvent
Common structure for all hardware events emitted by the SDK. This acts as the base data transfer object for the unified stream.
HardwareModule
Abstract base module defining the common lifecycle for hardware subsystems.