GpsConfig class

GPS configuration.

Constructors

GpsConfig({GpsAccuracy accuracy = GpsAccuracy.high, int intervalMs = 1000, double distanceFilterMeters = 1.0})
const

Properties

accuracy GpsAccuracy
final
distanceFilterMeters double
final
hashCode int
The hash code for this object.
no setterinherited
intervalMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited