data property
dynamic
data
final
The payload of the event, usually a Map or specialized model data.
Implementation
final dynamic data;
The payload of the event, usually a Map or specialized model data.
final dynamic data;