HardwareMode enum
Operation mode for the Hardware Plugin.
Values
- beginner → const HardwareMode
-
Simple, safe defaults with auto-permissions and robust error handling.
- performance → const HardwareMode
-
High performance, aggressive resource usage.
- advanced → const HardwareMode
-
Full manual control for advanced users.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HardwareMode> - A constant List of the values in this enum, in order of their declaration.