HardwareModule class abstract
Abstract base module defining the common lifecycle for hardware subsystems.
Constructors
Properties
-
eventStream
→ Stream<
HardwareEvent> -
Provides access to the raw event stream for this specific module.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< bool> - Disposes and releases hardware resources.
-
initialize(
) → Future< bool> - Initializes the hardware module.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited