eventStream property
Stream<HardwareEvent>
get
eventStream
Provides access to the raw event stream for this specific module.
Implementation
Stream<HardwareEvent> get eventStream;
Provides access to the raw event stream for this specific module.
Stream<HardwareEvent> get eventStream;