BatteryInfo class

Constructors

BatteryInfo({required double level, required bool isCharging, required String status, required double temperature})
BatteryInfo.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isCharging bool
final
level double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
temperature double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited