BluetoothDevice class

A discovered Bluetooth Low Energy device.

Constructors

BluetoothDevice({required String id, required String name, required int rssi, Map<String, dynamic>? serviceData})
const
BluetoothDevice.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceData Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited