CameraQuality enum

Preset camera preview sizes tuned for quality vs speed.

Inheritance
Available extensions

Values

low → const CameraQuality
const CameraQuality(640, 480)
medium → const CameraQuality
const CameraQuality(960, 540)
hd → const CameraQuality
const CameraQuality(1280, 720)
fullHd → const CameraQuality
const CameraQuality(1920, 1080)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CameraQuality>
A constant List of the values in this enum, in order of their declaration.