FileInfo class

Metadata for a file in device storage.

Constructors

FileInfo({required String name, required int size, required bool isDirectory, required DateTime lastModified})
FileInfo.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
final
lastModified DateTime
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
sizeFormatted String
Human-readable file size.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited