GpsLocation class
A GPS location update with accuracy and speed metadata.
Constructors
- GpsLocation({required double latitude, required double longitude, required double altitude, required double accuracy, required double speed, required DateTime timestamp})
-
const
- GpsLocation.fromMap(Map map)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited