HardwareException class

Structured hardware plugin error.

Implemented types

Constructors

HardwareException({required String message, String code = 'HARDWARE_ERROR', String? module})
const

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
module String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited