LocationData class

High-accuracy GPS/Location data containing coordinates and precision.

Constructors

LocationData({required double latitude, required double longitude, required double altitude, required double accuracy, required double speed})
Constructs LocationData.
LocationData.fromMap(Map map)
Creates LocationData from a raw data map.
factory

Properties

accuracy double
Horizontal accuracy in meters.
final
altitude double
Altitude in meters.
final
hashCode int
The hash code for this object.
no setterinherited
latitude double
Latitude in degrees.
final
longitude double
Longitude in degrees.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
Speed in meters per second.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited