LogConfig class

Constructors

LogConfig({String fileName = "nexora_log.csv", bool includeSensors = true, bool includeGPS = true, int intervalMs = 100})

Properties

fileName String
final
hashCode int
The hash code for this object.
no setterinherited
includeGPS bool
final
includeSensors bool
final
intervalMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited