SensorSample class

Raw accelerometer + gyroscope sample.

Constructors

SensorSample({required double x, required double y, required double z, required String sensorType, required DateTime timestamp})
const
SensorSample.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorType String
final
timestamp DateTime
final
x double
final
y double
final
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited