WifiInfo class

Constructors

WifiInfo({required String ssid, required String bssid, required int signalStrength, required String ipAddress})
WifiInfo.fromMap(Map map)
factory

Properties

bssid String
final
hashCode int
The hash code for this object.
no setterinherited
ipAddress String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalStrength int
final
ssid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited