SensorData class
Encapsulates sensor data from native hardware.
Constructors
- SensorData({required double x, required double y, required double z, required DateTime timestamp})
- SensorData.fromMap(Map map)
-
Factory constructor to create a SensorData from a map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited