AudioInputController class

Controller for capturing and adjusting physical hardware microphones.

Constructors

AudioInputController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectMicrophone(AudioInputDevice device) Future<bool>
Selects the target hardware microphone for recording (front, back, bottom, bluetooth, etc).
setGain(double gain) Future<bool>
Sets the input recording gain (sensitivity) (0.0 to 1.0).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited