AudioOutputController class

Controller for routing audio output channels and volume controls.

Constructors

AudioOutputController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getVolume() Future<double>
Gets the current system audio playback volume level (0.0 to 1.0).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
routeTo(AudioOutputRoute route) Future<bool>
Routes audio output to speakerphone, earpiece, bluetooth, or wired headsets.
setVolume(double level) Future<bool>
Sets the system audio playback volume level (0.0 to 1.0).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited