routeTo method
Routes audio output to speakerphone, earpiece, bluetooth, or wired headsets.
Implementation
Future<bool> routeTo(AudioOutputRoute route) {
return NexoraSdkPlatform.instance.routeAudioOutput(route);
}
Routes audio output to speakerphone, earpiece, bluetooth, or wired headsets.
Future<bool> routeTo(AudioOutputRoute route) {
return NexoraSdkPlatform.instance.routeAudioOutput(route);
}