FeedbackModule class
Module for controlling device haptics and vibration.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
haptic(
String type) → Future< void> - Triggers a native haptic pattern.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
vibrate(
{int durationMs = 50}) → Future< void> -
Triggers a standard vibration for the specified
durationMs.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited