HapticPattern enum

Supported haptic feedback patterns.

Inheritance
Available extensions

Values

impact → const HapticPattern

API Documentation for impact.

const HapticPattern('impact')
success → const HapticPattern

API Documentation for success.

const HapticPattern('success')
warning → const HapticPattern

API Documentation for warning.

const HapticPattern('warning')
error → const HapticPattern

API Documentation for error.

const HapticPattern('error')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
API Documentation for value;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HapticPattern>
A constant List of the values in this enum, in order of their declaration.