addGeofence method

Future<bool> addGeofence(
  1. String id,
  2. double lat,
  3. double lon,
  4. double radius,
)

Adds a virtual circular boundary trigger at the specified coordinates.

Triggers will be handled by the background intelligence system.

Implementation

Future<bool> addGeofence(String id, double lat, double lon, double radius) =>
    NexoraSdkPlatform.instance.addGeofence(id, lat, lon, radius);