NfcModule class
Module to interact with Near Field Communication (NFC) hardware on the device.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nfcTagStream
→ Stream<
Map< String, dynamic> > -
Returns a stream of discovered NFC tags and their payload/NDEF data.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startNfcScan(
) → Future< bool> - Starts listening/scanning for NFC tags.
-
stopNfcScan(
) → Future< bool> - Stops listening/scanning for NFC tags.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeNdefRecord(
{required String type, required String payload}) → Future< bool> - Writes an NDEF record to a discovered NFC tag.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited