PermissionsModule class
Permission status checks and settings helpers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAppSettings(
) → Future< bool> - Opens the host app settings page.
-
snapshot(
) → Future< HardwarePermissionSnapshot> - Returns a snapshot of all core hardware permissions.
-
status(
HardwarePermission permission) → Future< HardwarePermissionStatus> - Returns the current status for one hardware permission without prompting.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited