DeviceInfo class

Basic device and OS details for native-feeling Flutter apps.

Constructors

DeviceInfo({required String platform, required String manufacturer, required String model, required String osVersion, required String sdkVersion, required bool isPhysicalDevice, required int totalRamBytes, required int availableRamBytes, required String cpuArchitecture, required double screenRefreshRate, required String thermalState})
API Documentation for DeviceInfo.
const
DeviceInfo.fromMap(Map map)
API Documentation for DeviceInfo.fromMap.
factory

Properties

availableRamBytes int
API Documentation for availableRamBytes;.
final
cpuArchitecture String
API Documentation for cpuArchitecture;.
final
hashCode int
The hash code for this object.
no setteroverride
isPhysicalDevice bool
API Documentation for isPhysicalDevice;.
final
manufacturer String
API Documentation for manufacturer;.
final
model String
API Documentation for model;.
final
osVersion String
API Documentation for osVersion;.
final
platform String
API Documentation for platform;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenRefreshRate double
API Documentation for screenRefreshRate;.
final
sdkVersion String
API Documentation for sdkVersion;.
final
thermalState String
API Documentation for thermalState;.
final
totalRamBytes int
API Documentation for totalRamBytes;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override