NexoraSdkPlatform class abstract

The interface that implementations of NexoraSdk must implement.

Inheritance
  • Object
  • PlatformInterface
  • NexoraSdkPlatform
Implementers

Constructors

NexoraSdkPlatform()

Properties

audioStream Stream<AudioFrame>
no setter
bluetoothStream Stream<BleDevice>
no setter
cameraStream Stream<CameraFrame>
no setter
hashCode int
The hash code for this object.
no setterinherited
locationStream Stream<LocationData>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorStream Stream<HardwareEvent>
no setter
unifiedStream Stream<HardwareEvent>
no setter

Methods

addGeofence(String id, double lat, double lon, double radius) Future<bool>
authenticate(String reason) Future<bool>
canAuthenticate() Future<bool>
clearCache() Future<bool>
connectDevice(String id) Future<bool>
deleteFile(String fileName) Future<bool>
discoverServices(String deviceId) Future<List<String>>
fileExists(String fileName) Future<bool>
flipCamera() Future<bool>
getAppDirectory() Future<String?>
getBatteryInfo() Future<BatteryInfo?>
getCacheDirectory() Future<String?>
getExternalDirectory() Future<String?>
getPlatformVersion() Future<String?>
getStorageInfo() Future<StorageInfo?>
getWifiInfo() Future<WifiInfo?>
hapticFeedback(String type) Future<void>
listFiles() Future<List<FileInfo>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(String fileName) Future<Uint8List?>
readFile(String fileName) Future<String?>
requestAudioPermission() Future<bool>
requestBluetoothPermission() Future<bool>
requestCameraPermission() Future<bool>
requestLocationPermission() Future<bool>
requestPermissions() Future<bool>
sendData(String deviceId, String serviceId, String charId, List<int> data) Future<bool>
setBackgroundLocationEnabled(bool enabled) Future<bool>
setFlash(bool on) Future<bool>
setVisionMode({bool barcode = false, bool face = false}) Future<bool>
setZoom(double level) Future<bool>
startAudio({bool enableFFT = false, bool streamBytes = false, int updateIntervalMs = 80}) Future<bool>
startBluetoothScan() Future<bool>
startCamera({int width = 1280, int height = 720}) Future
startHardwareLogging(LogConfig config) Future<bool>
startLocation() Future<bool>
startSensor({int frequencyHz = 60}) Future<bool>
stopAudio() Future<bool>
stopBluetoothScan() Future<bool>
stopCamera() Future<bool>
stopHardwareLogging() Future<bool>
stopLocation() Future<bool>
stopSensor() Future<bool>
toString() String
A string representation of this object.
inherited
vibrate(int durationMs) Future<void>
writeBytes(String fileName, Uint8List bytes) Future<String?>
writeFile(String fileName, String content) Future<String?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NexoraSdkPlatform
getter/setter pair