HardwareCameraController class

Constructors

HardwareCameraController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capturePhoto() Future<Uint8List?>
Captures a photo and returns the raw bytes or file path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchCamera() Future<void>
Switch between front and back camera
toggleFlash() Future<void>
Toggle the device flash / torch
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited