HardwareEvent class

Constructors

HardwareEvent({required String module, required dynamic data, required DateTime timestamp})
const
HardwareEvent.fromMap(Map map)
factory

Properties

data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
module String
Identifies the source subsystem: 'bluetooth' | 'gps' | 'sensor' | 'camera'
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited