CameraFrame class

A raw camera frame delivered via binary channel.

Constructors

CameraFrame({required Uint8List bytes, required int width, required int height, String format = 'bgra'})
const

Properties

bytes Uint8List
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
no setter
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited