CameraFrame class
A raw camera frame delivered via binary channel.
Constructors
- CameraFrame({required Uint8List bytes, required int width, required int height, String format = 'bgra'})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited