SensorSample class
Raw accelerometer + gyroscope sample.
Constructors
- SensorSample({required double x, required double y, required double z, required String sensorType, required DateTime timestamp})
-
const
- SensorSample.fromMap(Map map)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited