WifiInfo class
Information about the current WiFi connection.
Constructors
Properties
- bssid → String
-
The Basic Service Set Identifier (BSSID).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String
-
Current IPv4 address.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signalStrength → int
-
Relative signal strength (0-100 or dBm depending on platform).
final
- ssid → String
-
The Service Set Identifier (SSID).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited