AudioModule class
Module for raw audio capture and signal analysis.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → AudioInputController
-
Controls the microphone selection and recording gain features.
final
- isRunning → bool
-
API Documentation for _isRunning;.
no setter
- lastEnableFFT → bool
-
API Documentation for _lastEnableFFT;.
no setter
- lastStreamBytes → bool
-
API Documentation for _lastStreamBytes;.
no setter
- lastUpdateIntervalMs → int
-
API Documentation for _lastUpdateIntervalMs;.
no setter
- output → AudioOutputController
-
Controls the speaker and audio output routing features.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AudioFrame> -
A stream of AudioFrame objects containing raw bytes and FFT spectrum.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{bool enableFFT = false, bool streamBytes = false, int updateIntervalMs = 80, bool autoRequestPermission = true}) → Future< bool> - Starts capturing audio from the device microphone.
-
startWithOptions(
AudioOptions options, {bool autoRequestPermission = true}) → Future< bool> - Starts the audio capture with granular, fully-customized native options.
-
stop(
) → Future< bool> - Stops audio capture and analysis.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited