AudioModule class
Module for raw audio capture and signal analysis.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AudioFrame> -
A stream of AudioFrame objects containing raw bytes and FFT spectrum.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{bool enableFFT = false, bool streamBytes = false, int updateIntervalMs = 80}) → Future< bool> - Starts capturing audio from the device microphone.
-
stop(
) → Future< bool> - Stops audio capture and analysis.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited