start method
Starts capturing audio from the device microphone.
Set enableFFT to true to receive frequency spectrum data in the stream.
Keep streamBytes false for lightweight visualizers that only need FFT.
Implementation
Future<bool> start({
bool enableFFT = false,
bool streamBytes = false,
int updateIntervalMs = 80,
}) => NexoraSdkPlatform.instance.startAudio(
enableFFT: enableFFT,
streamBytes: streamBytes,
updateIntervalMs: updateIntervalMs,
);