BiometricModule class
Module for secure biometric authentication (FaceID/Fingerprint).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
{String reason = "Authenticate to continue"}) → Future< bool> -
Triggers a system biometric prompt with the specified
reason. -
canAuthenticate(
) → Future< bool> - Checks if the device supports and has biometrics configured.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited