BluetoothModule class
Module for high-performance Bluetooth Low Energy (BLE) management.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanStream
→ Stream<
BleDevice> -
A stream of BleDevice objects discovered during a scan.
no setter
Methods
-
connect(
String id) → Future< bool> -
Attempts to connect to a specific BLE device by its
id. -
discoverServices(
String deviceId) → Future< List< String> > - Discovers GATT services for a connected device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendData(
String deviceId, String serviceId, String charId, List< int> data) → Future<bool> - Sends raw byte data to a specific GATT characteristic.
-
startScan(
) → Future< bool> - Starts scanning for nearby BLE devices. Discovered devices are delivered via the scanStream.
-
stopScan(
) → Future< bool> - Stops the active BLE scan.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited