BluetoothModule class

Modular Bluetooth LE Module. Features scanning, connecting, and characteristic streaming.

Constructors

BluetoothModule()

Properties

deviceStream Stream<Map>
Real-time BLE device and data stream.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String deviceId) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScan() Future<bool>
stopScan() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventChannel → const EventChannel
methodChannel → const MethodChannel