CameraModule class
Module for high-performance raw camera frame streaming.
Constructors
- CameraModule()
- Internal constructor.
Properties
-
frameStream
→ Stream<
CameraFrame> -
Alias for stream specific to camera frames.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
CameraFrame> -
Stream of raw CameraFrame objects for real-time processing.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{int width = 640, int height = 480}) → Future< bool> -
Starts the camera with requested
widthandheight. -
stop(
) → Future< bool> - Stops the camera and releases the hardware lock.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited