CameraModule class

Performance-optimized Camera module with Binary Channel Support.

Constructors

CameraModule()

Properties

frameStream Stream<Uint8List>
High-performance raw frame stream using BasicMessageChannel.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<bool>
stop() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited