addGeofence method
Adds a virtual circular boundary trigger at the specified coordinates.
Triggers will be handled by the background intelligence system.
Implementation
Future<bool> addGeofence(String id, double lat, double lon, double radius) =>
NexoraSdkPlatform.instance.addGeofence(id, lat, lon, radius);