NativeModule class
Native convenience APIs that make Flutter apps feel platform-integrated.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyText(
String text) → Future< bool> -
Copies
textinto the system clipboard. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openUrl(
String url) → Future< bool> - Opens a URL or platform deep link.
-
pasteText(
) → Future< String?> - Reads plain text from the system clipboard.
- Opens the platform share sheet with text and an optional subject.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited