SensorModule class
Module for motion and environmental hardware sensors.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
HardwareEvent> -
A stream of raw HardwareEvent data from the motion sensors.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{int frequencyHz = 60}) → Future< bool> -
Starts the accelerometer and gyroscope at the specified
frequencyHz. -
stop(
) → Future< bool> - Stops all sensor monitoring.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited