SensorModule class
Module for motion and environmental hardware sensors.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
API Documentation for _isRunning;.
no setter
- lastFrequencyHz → int
-
API Documentation for _lastFrequencyHz;.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
SensorData> -
A stream of SensorData objects captured in real-time from the motion sensors.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{int frequencyHz = 60}) → Future< bool> -
Starts the accelerometer and gyroscope at the specified
frequencyHz. -
startWithOptions(
SensorOptions options) → Future< bool> - Starts accelerometer/gyroscope tracking with granular native customizations.
-
stop(
) → Future< bool> - Stops all sensor monitoring.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited