SensorModule class

Module for accessing hardware motion sensors like the Accelerometer.

Constructors

SensorModule()
Internal constructor.

Properties

accelerometerStream Stream<HardwareEvent>
Alias for stream specific to accelerometer data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<HardwareEvent>
Throttled stream of accelerometer data events.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({int frequencyHz = 60}) Future<bool>
Starts the sensor with a specific frequencyHz (default 60Hz).
stop() Future<bool>
Stops the sensor stream.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited