SecureStorageModule class

Secure Storage Module supporting AES-256 encrypted file writes/reads. Uses Android KeyStore (AES-GCM) on Android and iOS Keychain on iOS.

Constructors

SecureStorageModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteSecureFile(String fileName) Future<bool>
Deletes a secure file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readSecureFile(String fileName) Future<String?>
Reads and decrypts data from a file.
readSecureJson<T extends Object>(String fileName) Future<T?>
Reads a JSON value securely.
toString() String
A string representation of this object.
inherited
writeSecureFile(String fileName, String content) Future<bool>
Writes encrypted data to a file.
writeSecureJson(String fileName, Object? value) Future<bool>
Writes a JSON-serializable value securely.

Operators

operator ==(Object other) bool
The equality operator.
inherited